*=====================================================================================*
*                                  preparation_description.do                         *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
* Buyukkececi and Leopold 2020, replication files                              		  *
* last update: 18 September 2020                                                      *
* data: BIOSIB 1984-2016, version 33, release 2018                                    *
*-------------------------------------------------------------------------------------*

*-----------------------------------------------------------------------------*
*  Saving each marriage and cohabitation spell separately                     *
*-----------------------------------------------------------------------------*
* Marriage spells
foreach i of num 1/13 {
use "$data\biomarsy.dta", clear
keep if spellnr==`i'
rename spelltyp marryspelltyp`i'
rename begin marryagebegin`i'
rename end marryageend`i'
save "$data\maryearly`i'", replace
}

* Cohabitation spells
foreach i of num 1/23 {
use "$data\biocoupley.dta", clear
keep if spellnr==`i'
rename spelltyp cohabtype`i'
rename begin cohabagebegin`i'
rename end cohabegeend`i'
save "$data\cohabyearly`i'", replace
}

* Opening SOEP's siblings data
use "$data\biosib.dta", clear

* From other files
merge m:1 persnr using "$data\biobirth.dta", keep (1 3) nogen keepusing(kidgeb01-kidgeb03)
merge m:1 persnr using "$data\ppfad.dta", keep (1 3) nogen keepusing(letztbef migback psample gebmonat loc1989 cid)
* Restricting the sample to individuals with one sibling
sort famcount
quietly by famcount:  gen dup = cond(_N==1,0,_n)
keep if dup==1 & num_sib==2 | dup==2 & num_sib==2
* Dropping siblings who never participated into any survey
drop if letztbef==-2
* Dropping if the brother or sister is missing
gen sib=famcount
bysort sib: drop if _N<2
* Last surveyed either ego or sibling
egen sibletztbef=total(letztbef),by(sib)
replace sibletztbef=sibletztbef-letztbef
gen finalyear=letztbef if letztbef<=sibletztbef
replace finalyear=sibletztbef if sibletztbef<letztbef
* Sibling's birth year
egen gebjahrsib=total(gebjahr),by(sib)
replace gebjahrsib=gebjahrsib-gebjahr
* Create duration
gen dur=letztbef-gebjahr-14
expand dur
by persnr, sort: gen age=_n
replace age=age+14
gen year=age+gebjahr
* Partnership history
do "$data\02_partnership.do"

///First marriageyear///
bysort persnr: egen firstmarryyear2=min(year) if marsta2==1
bysort persnr: egen firstmarryyear=mean(firstmarryyear2)
drop firstmarryyear2
bysort persnr: egen firstdivorceyear2=min(year) if marsta2==3
bysort persnr: egen firstdivorceyear=mean(firstdivorceyear2)
drop firstdivorceyear2
bysort persnr: egen firstcohabyear2=min(year) if marsta2==2
bysort persnr: egen firstcohabyear=mean(firstcohabyear2)
drop firstcohabyear2

* Sib first child
egen sibfirstchild2=total(kidgeb01) if age==15, by(sib)
replace sibfirstchild2=sibfirstchild2-kidgeb01
bysort persnr: egen sibfirstchild=mean(sibfirstchild2)
drop sibfirstchild2
* Sib first marry
replace firstmarryyear=-2 if firstmarry==.
egen sibfirstmarry2=total(firstmarryyear) if age==15, by(sib)
replace sibfirstmarry2=sibfirstmarry2-firstmarryyear
bysort persnr: egen sibfirstmarry=mean(sibfirstmarry2)
drop sibfirstmarry2
* Sib first divorce
replace firstdivorceyear=-2 if firstdivorceyear==.
egen sibfirstdivorce2=total(firstdivorceyear) if age==15, by(sib)
replace sibfirstdivorce2=sibfirstdivorce2-firstdivorceyear
bysort persnr: egen sibfirstdivorce=mean(sibfirstdivorce2)
drop sibfirstdivorce2

* Predictors and outcomes
* Sibling dummies
* Childbearing
gen sibchild=0
replace sibchild=1 if sibchild12==1 | sibchild24==1 | sibchild36==1
gen sibchild36more=0 if year<sibfirstchild+3 & sibfirstchild!=-2 | sibfirstchild==-2
replace sibchild36more=1 if year>sibfirstchild+2 & sibfirstchild!=-2
* Marriage
gen sibmarry=0
replace sibmarry=1 if sibmarry12==1 | sibmarry24==1 | sibmarry36==1
gen sibmarry36more=0 if year<sibfirstmarry+3 & sibfirstmarry!=-2 | sibfirstmarry==-2
replace sibmarry36more=1 if year>sibfirstmarry+2 & sibfirstmarry!=-2
* Divorce
gen sibdivorce=0
replace sibdivorce=1 if sibdivorce12==1 | sibdivorce24==1 | sibdivorce36==1
gen sibdivorce36more=0 if year<sibfirstdivorce+3 & sibfirstdivorce!=-2 | sibfirstdivorce==-2
replace sibdivorce36more=1 if year>sibfirstdivorce+2 & sibfirstdivorce!=-2

* Ego's childbearing
gen y=0 if year<kidgeb01 & kidgeb01!=-2 | kidgeb01==-2
replace y=1 if year==kidgeb01 & kidgeb01!=-2
* Ego's marriage
gen y2=0 if year<firstmarryyear & firstmarryyear!=-2 | firstmarryyear==-2
replace y2=1 if year==firstmarryyear & firstmarryyear!=-2
gen child=0
replace child=1 if year>=kidgeb01 & kidgeb01!=-2
* Ego's divorce
gen y3=0 if year<firstdivorceyear & firstdivorceyear!=-2 & year>=firstmarryyear & firstmarryyear!=-2 | firstdivorceyear==-2 & year>=firstmarryyear & firstmarryyear!=-2
replace y3=1 if year==firstdivorceyear & firstdivorceyear!=-2

///Parental controls///
merge m:1 persnr using "$data\bioparen.dta", keep(1 3) nogen keepusing(fybirth mybirth fnr mnr fydeath mydeath fsedu msedu locchildh fnat mnat fegp megp living1 fprofedu mprofedu)
* Father's education
gen fatedu=0 if fprofedu==-2 | fprofedu==10
replace fatedu=1 if fprofedu==20
replace fatedu=2 if fprofedu!=. & fprofedu>20
replace fatedu=3 if fprofedu==31 | fprofedu==32
replace fatedu=-2 if fatedu==.
bysort sib: egen fatedunew=total(fatedu) if age==15
replace fatedunew=fatedunew-fatedu
replace fatedu=. if fatedu==-2
replace fatedu=fatedunew if fatedu==. & fatedunew!=-2
bysort persnr: egen fatedu2=mean(fatedu)
drop fatedunew fatedu
rename fatedu2 fatedu
label def fatedu 0 "No vocational training" 1 "Vocational training" 2 "Other vocational training" 3 "College"
label val fatedu fatedu
* Mother's education
gen motedu=0 if mprofedu==-2 | mprofedu==10
replace motedu=1 if mprofedu==20
replace motedu=2 if mprofedu!=. & mprofedu>20
replace motedu=3 if mprofedu==31 | mprofedu==32
replace motedu=-2 if motedu==.
bysort sib: egen motedunew=total(motedu) if age==15
replace motedunew=motedunew-motedu
replace motedu=. if motedu==-2
replace motedu=motedunew if motedu==. & motedunew!=-2
bysort persnr: egen motedu2=mean(motedu)
drop motedunew motedu
rename motedu2 motedu
label val motedu fatedu
* Intact family
gen intact=0
replace intact=1 if living1==15
* Occupational classification of fathers
gen fatclass=0 if fegp>1 & fegp<5
replace fatclass=1 if fegp==8 | fegp==1
replace fatclass=2 if fegp==9
replace fatclass=3 if fegp==10 | fegp==11
replace fatclass=4 if fegp>4 & fegp<7
replace fatclass=0 if megp>1 & megp<5 & fatclass==.
replace fatclass=1 if megp==8 & fatclass==. | megp==1 & fatclass==.
replace fatclass=2 if megp==9 & fatclass==.
replace fatclass=3 if megp==10 & fatclass==. | megp==11 & fatclass==.
replace fatclass=4 if megp>4 & megp<7 & fatclass==.

replace fatclass=-2 if fatclass==.
bysort sib: egen fatclassnew=total(fatclass) if age==15
replace fatclassnew=fatclassnew-fatclass
replace fatclass=. if fatclass==-2
replace fatclass=fatclassnew if fatclass==. & fatclassnew!=-2
bysort persnr: egen fatclass2=mean(fatclass)
drop fatclassnew fatclass
rename fatclass2 fatclass
label define fatclass 0 "Blue-Collar" 1 "Upper White-Collar" 2 "Lower White-Collar" 3 "Farmer" 4 "Self-employed"
label val fatclass fatclass
* Place of birth
gen urbanization=locchildh if locchildh>0 & locchildh!=.
label def urbanization 1 "Big City" 2 "Middle City" 3 "Small Town" 4 "Land"
label val urbanization urbanization
replace urbanization=-2 if urbanization==.
bysort sib: egen urbanizationnew=total(urbanization) if age==15
replace urbanizationnew=urbanizationnew-urbanization
replace urbanization=. if urbanization==-2
replace urbanization=urbanizationnew if urbanization==. & urbanizationnew!=-2
bysort persnr: egen urbanization2=mean(urbanization)
drop urbanizationnew urbanization
rename urbanization2 urbanization
* Immigrant status
gen migrant=0
replace migrant=1 if fnat==2 | mnat==2
* Education
merge m:1 persnr using "$data\pgen.dta", keep(1 3) nogen keepusing(eduisced pgbilzeit)
rename eduisced educ
* Employment
merge m:1 persnr using "$data\biojob.dta", keep(1 3) nogen keepusing(agefjob siops) 
gen ageatfjob=agefjob if agefjob!=. & agefjob>0
gen treiman=siops if siops!=. & siops>0
* Father alive
gen fatalive=0 if fydeath!=. & fydeath>0 & year<fydeath | fydeat==-2
replace fatalive=1 if  fydeath!=. & fydeath>0 & year>=fydeath
* Mother alive
gen matalive=0 if mydeath!=. & mydeath>0 & year<mydeath | mydeat==-2
replace matalive=1 if  mydeath!=. & mydeath>0 & year>=mydeath
* Sibship position
gen sibship=0 if sex==1 & gebjahr>=gebsib1
replace sibship=1 if sex==1 & gebjahr<gebsib1
replace sibship=2 if sex==2 & gebjahr>=gebsib1
replace sibship=3 if sex==2 & gebjahr<gebsib1
label def sibship 0 "Older brother" 1 "Younger brother" 2 "Older sister" 3 "Younger sister"
label val sibship sibship
* Mother's age at first birth
gen motagebirth=gebjahr-mybirth if mybirth!=. & mybirth>0 & gebjahr>gebsib1
replace motagebirth=gebsib1-mybirth if mybirth!=. & mybirth>0 & gebjahr<gebsib1
* East/West
gen east=0
replace east=1 if loc1989==1
replace pgbilzeit=0 if pgbilzeit==-2
* Cohort
gen cohort=0 if gebjahr<1950
replace cohort=1 if gebjahr>1949 & gebjahr<1965
replace cohort=2 if gebjahr>1964 & gebjahr<1975
replace cohort=3 if gebjahr>1974 & gebjahr<1985
replace cohort=4 if gebjahr>1984
* Age difference between the siblings
gen agedif=abs(gebjahr-gebjahrsib)

save "$data\data.dta", replace